# Ritual PyArweave

This directory wraps the [pyarweave](https://github.com/ritual-net/pyarweave)
repository, which is a fork of the `pyarweave` project with some additional
features and bug fixes. The library is packaged as `ritual-pyarweave` and
is used as a dependency for the `ritual-arweave` library & CLI tool.
